@@ -69,6 +69,9 @@ class CLI(object):
 		self.executable = executable
 		self.arguments = self.Arguments(executable=self.executable, docs=self.docs, stop=self.stop)
 		self.arguments.documentation = self.documentation = self.__create_docs__()
+		self.options = self.Options(attributes={
+			"arguments":self.arguments,
+		})
 
 		#
 	class Arguments(object):
@@ -76,6 +79,8 @@ class CLI(object):
 			self.docs = docs
 			self.stop = stop
 			self.executable = executable
+		def iterate(self):
+			return sys.argv
 		def present(self, argument):
 			if isinstance(argument, str):
 				return argument_present(argument)
@@ -107,6 +112,84 @@ class CLI(object):
 							sys.tracebacklimit = -1
 							sys.traceback_limit = -1
 							raise UnkownArgumentError(error)
+	class Options(object):
+		def __init__(self, attributes={}):
+			self.assign(attributes)
+		# iterate over self keys & variables.
+		def items(self):
+			return vars(self).items()
+		def keys(self):
+			return list(vars(self).keys())
+		def values(self):
+			return list(vars(self).values())
+		def dict(self, serializable=False):
+			dictionary = {}
+			for key, value in self.items():
+				if serializable:
+					if isinstance(value, object):
+						value = str(value)
+					elif value == "True": value = True
+					elif value == "False": value = False
+					elif value == "None": value = None
+				dictionary[key] = value
+			return dictionary
+		# assign self variables by dictionary.
+		def assign(self, dictionary):
+			if not isinstance(dictionary, dict):
+				raise TypeError("You can only self assign with a dictionary as parameter.")
+			for key,value in dictionary.items():
+				if value in ["False", "false"]: value = False
+				elif value in ["True", "true"]: value = True
+				elif value in ["None", "none", "null", "nan"]: value = None
+				else:
+					if isinstance(value, str):
+						if "." in str(value):
+							try: value = float(value)
+							except: a=1
+						else:
+							try: value = int(value)
+							except: a=1
+				self[key] = value
+		# unpack keys as tuple.
+		def unpack(self, 
+			# the variable keys (#1 parameter).
+			keys=[],
+		):
+			list = []
+			for key in keys:
+				list.append(self[key])
+			return list
+		# clean default values.
+		def clean(self):
+			for i in ["error", "message", "success"]:
+				del self[i]
+				#except: a=1
+			return self
+		# count items.
+		def __len__(self):
+			return len(self.keys())
+		# support item assignment.
+		def __setitem__(self, key, value):
+			setattr(self, key, value)
+		def __getitem__(self, key):
+			return getattr(self, key)
+		def __delitem__(self, key):
+			delattr(self, key)
+		# string format.
+		def __str__(self):
+			return json.dumps(self.dict(serializable=True), indent=4) # necessary for str(self)
+			return self.dict(serializable=True) # seems to work for django.
+			if isinstance(self, dict):
+				return json.dumps(self, indent=4)
+			else:
+				return json.dumps(self.dict(), indent=4)
+		def json(self,):
+			return json.dumps(self.dict(serializable=True), indent=4)
+			return self.dict(serializable=True) # seems to work for django.
+			return self.dict(serializable=True)
+			return json.dumps(self.dict(serializable=True), indent=4)
+			return json.dumps(self)
+			return json.dumps(self, default=lambda o: o.__dict__)
 	def stop(self,
 		# success exit.
 		success=True,
@@ -230,7 +313,8 @@ class CLI(object):
 		self.options_str = self.arguments.options_str = o = __str_representable__(self.options)
 		n = __str_representable__(self.notes)
 		c = f"\nAuthor: {self.author}. \nCopyright: © {self.author} {datetime.datetime.today().strftime('%Y')}. All rights reserved."
-		doc = "Usage: "+self.alias+" <mode> <options> \nModes:\n"+m
+		doc = "Usage: "+self.alias+" <mode> <options> "
+		if m != "": doc += "\nModes:\n"+m
 		if o != "": doc += "\nOptions:\n"+o
 		if n != "": doc += "\nNotes:\n"+n
 		doc += c
