@@ -4,6 +4,9 @@
 # imports.
 import os, sys, ast, json, glob, platform, subprocess, random
 from fil3s import Files, Formats
+from r3sponse import r3sponse
+
+# functions.
 def __get_operating_system__():
 	os = platform.system().lower()
 	if os in ["darwin"]: return "osx"
